@@ -17,10 +17,19 @@ rm_ext <- function(path) {
 #' assign b if a is nothing
 #' @noRd
 `%||%` <- function(a, b) {
+  if (length(a) > 1) {
+    return(a)
+  }
+  if (is.null(a)) {
+    return(b)
+  }
   if (length(a) == 0) {
     return(b)
   }
-  if (is.na(a) || is.null(a) || a == "") {
+  if (is.na(a)) {
+    return(b)
+  }
+  if (a == "") {
     return(b)
   }
   a
@@ -50,13 +59,15 @@ null2na <- function(x) {
   x
 }
 
+# nocov start
 mock_if_no_auth <- function() {
   if (!nettskjemar::ns_has_auth()) {
-    Sys.setenv(NETTSKJEMA_CLIENT_ID = "a1b2c3d4-e5f6-7890-abcd-ef1234567890")
     # nolint start
     Sys.setenv(
+      NETTSKJEMA_CLIENT_ID = "a1b2c3d4-e5f6-7890-abcd-ef1234567890",
       NETTSKJEMA_CLIENT_SECRET = "aB3xK9mP2vQ8fR7nL98Mcs81sT4uY6wE5zC0hJ9iO3kM8pN2qA7bD1gF4jH6lS9vX3nR5mT8"
     )
     # nolint end
   }
 }
+# nocov end
