@@ -3,7 +3,8 @@ library("vcr")
 
 invisible(vcr::vcr_configure(
   filter_sensitive_data = list(
-    "<<CLIENT_SECRET>>" = Sys.getenv("NETTSKJEMA_CLIENT_SECRET")
+    "<<CLIENT_SECRET>>" = Sys.getenv("NETTSKJEMA_CLIENT_SECRET"),
+    "<<REDACTED_BEARER>>" = "Bearer [A-Za-z0-9\\._-]+"
   ),
   dir = vcr::vcr_test_path("_vcr")
 ))
@@ -27,5 +28,5 @@ attachment_id <- 538819
 
 # nolint start
 mock_client_id = "a1b2c3d4-e5f6-7890-abcd-ef1234567890"
-mock_client_secret = "aB3xK9mP2vQ8fR7nL98Mcs81sT4uY6wE5zC0hJ9iO3kM8pN2qA7bD1gF4jH6lS9vX3nR5mT8"
+mock_client_secret = "aB3xK9mP2vQ8_R7nL98Mcs81sT4uY6wE5zC0hJ9iO3kM8pN2qA7bD1gF4jH6lS-9vX3nR5mT"
 # nolint end
